==> haskell-th-orphans-0.13.12-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-orphans
version:              0.13.12
visibility:           public
id:                   th-orphans-0.13.12-B6w1dp4FnIHFYeWrWx64bR
key:                  th-orphans-0.13.12-B6w1dp4FnIHFYeWrWx64bR
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  4545c7b15966967ace62d4de0cdf9816
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-orphans-0.13.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-orphans-0.13.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-orphans-0.13.12
hs-libraries:         HSth-orphans-0.13.12-B6w1dp4FnIHFYeWrWx64bR
depends:
    base-4.15.0.0 mtl-2.2.2 template-haskell-2.17.0.0
    th-compat-0.1.3-2xsjzS6ToESFmit6gFq906
    th-expand-syns-0.4.8.0-GOqwnEssAEwBXuaxb9Uucf
    th-lift-0.8.2-F0VVOrB5SZgFNS1AEtieR9
    th-lift-instances-0.1.18-1ATWYqgYDqpFKgZryCNWvv
    th-reify-many-0.1.10-3ITM56qIweE1m1sRUTAqJ9

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.12-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-orphans
version:              0.13.12
visibility:           public
id:                   th-orphans-0.13.12-Jd8Q4328jCP6yjiduvUS3N
key:                  th-orphans-0.13.12-Jd8Q4328jCP6yjiduvUS3N
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  d634d6c3e8e2b58e46a35e15b83b3ea7
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/th-orphans-0.13.12
library-dirs:         /usr/lib/ghc-9.0.1/site-local/th-orphans-0.13.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/th-orphans-0.13.12
hs-libraries:         HSth-orphans-0.13.12-Jd8Q4328jCP6yjiduvUS3N
depends:
    base-4.15.0.0 mtl-2.2.2 template-haskell-2.17.0.0
    th-compat-0.1.3-Alb5G0Mx7NV2GGai26wKcK
    th-expand-syns-0.4.8.0-LDfbhMFhDRp85cfKjNVwj0
    th-lift-0.8.2-F0VVOrB5SZgFNS1AEtieR9
    th-lift-instances-0.1.18-F71qrddrmFfCpYZPg53eRb
    th-reify-many-0.1.10-1zrAhNMsPUXAUZaEOIBXG8

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
